@@ -1242,9 +1242,9 @@ _edje_box_recalc_apply(Edje *ed, Edje_Real_Part *ep, Edje_Calc_Params *p3, Edje_
 	evas_object_smart_calculate(ep->object);
      }
    evas_object_size_hint_min_get(ep->object, &min_w, &min_h);
-   if (chosen_desc->box.min.h)
+   if (chosen_desc->box.min.h && (p3->w < min_w))
      p3->w = min_w;
-   if (chosen_desc->box.min.v)
+   if (chosen_desc->box.min.v && (p3->h < min_h))
      p3->h = min_h;
 }
 
